@@ -1,12 +1,9 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE TypeFamilies #-}
 
-#if __GLASGOW_HASKELL__ >= 706
-{-# LANGUAGE PolyKinds #-}
-#endif
-
-#if __GLASGOW_HASKELL__ >= 800 && __GLASGOW_HASKELL__ < 806
+#if __GLASGOW_HASKELL__ < 806
 {-# LANGUAGE TypeInType #-}
 #endif
 
@@ -22,22 +19,15 @@ https://github.com/haskell-compat/deriving-compat/issues/24.
 -}
 module GH24Spec (main, spec) where
 
-#if __GLASGOW_HASKELL__ >= 800
 import Data.Deriving
-#endif
-
-import Prelude ()
-import Prelude.Compat
 
 import Test.Hspec
 
-#if __GLASGOW_HASKELL__ >= 800
 data family P (a :: j) (b :: k)
 data instance P (a :: k) k = MkP deriving (Eq, Ord)
 
 $(deriveEnum 'MkP)
 $(deriveIx   'MkP)
-#endif
 
 main :: IO ()
 main = hspec spec
